From e6cf2e31d2ff8c922824a4b317f51b1187472a87 Mon Sep 17 00:00:00 2001
From: Guo Xinle <guoxinle1@huawei.com>
Date: Mon, 22 Feb 2021 10:32:59 +0800
Subject: [PATCH 1/3] Net: add the verify that iothread does not exist

If not configured net iothread, but net set iothread
name in parameter, it will start successfully.
Add some verify code.

Signed-off-by: Guo Xinle <guoxinle1@huawei.com>
---
 device_model/src/virtio/net.rs | 10 ++++++++++
 1 file changed, 10 insertions(+)

diff --git a/device_model/src/virtio/net.rs b/device_model/src/virtio/net.rs
index 23d0899..1ddc253 100644
--- a/device_model/src/virtio/net.rs
+++ b/device_model/src/virtio/net.rs
@@ -558,6 +558,16 @@ impl Net {
 impl VirtioDevice for Net {
     /// Realize vhost virtio network device.
     fn realize(&mut self) -> Result<()> {
+        // if iothread not found, return err
+        if self.net_cfg.iothread.is_some()
+            && EventLoop::get_ctx(self.net_cfg.iothread.as_ref()).is_none()
+        {
+            bail!(
+                "IOThread {:?} of Net is not configured in params.",
+                self.net_cfg.iothread,
+            );
+        }
+
         self.device_features = 1 << VIRTIO_F_VERSION_1
             | 1 << VIRTIO_NET_F_CSUM
             | 1 << VIRTIO_NET_F_GUEST_CSUM
-- 
2.27.0

